pub struct ActorSupervisionEvent {
pub actor_id: ActorId,
pub display_name: Option<String>,
pub occurred_at: SystemTime,
pub actor_status: ActorStatus,
pub message_headers: Option<Flattrs>,
}Expand description
This is the local actor supervision event. Child actor will propagate this event to its parent.
Fields
actor_id: ActorIdThe actor id of the child actor where the event is triggered.
display_name: Option<String>Friendly display name, if the actor class customized it.
occurred_at: SystemTimeThe time when the event is triggered.
actor_status: ActorStatusStatus of the child actor.
message_headers: Option<Flattrs>If this event is associated with a message, the message headers.
Implementations
Sourceimpl ActorSupervisionEvent
impl ActorSupervisionEvent
Sourcepub fn new(
actor_id: ActorId,
display_name: Option<String>,
actor_status: ActorStatus,
message_headers: Option<Flattrs>,
) -> Self
pub fn new( actor_id: ActorId, display_name: Option<String>, actor_status: ActorStatus, message_headers: Option<Flattrs>, ) -> Self
Create a new supervision event. Timestamp is set to the current time.
Sourcepub fn caused_by(&self) -> &ActorSupervisionEvent
pub fn caused_by(&self) -> &ActorSupervisionEvent
Walk the UnhandledSupervisionEvent chain to the root-cause
event — the first event whose status is not
UnhandledSupervisionEvent.
Sourcepub fn actually_failing_actor(&self) -> Option<&ActorSupervisionEvent>
pub fn actually_failing_actor(&self) -> Option<&ActorSupervisionEvent>
Walk the UnhandledSupervisionEvent chain to find the root-cause
actor that originally failed.
Returns None if the event is not a failure. Always returns the
leaf of the chain — the actor whose status is the root cause,
even if that leaf is a non-failure (e.g. a stopped process).
Sourcepub fn failure_report(&self) -> Option<String>
pub fn failure_report(&self) -> Option<String>
Produce a concise failure report. Returns None for non-failure
events.